==> mingw-w64-qgis-3.36.2-4.src.tar.zst: qgis-3.36.2/src/analysis/processing/qgsalgorithmuniquevalueindex.h <==
/***************************************************************************
                         qgsalgorithmuniquevalueindex.h
                         ------------------------------
    begin                : January 2018
    copyright            : (C) 2018 by Nyall Dawson
    email                : nyall dot dawson at gmail dot com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef QGSALGORITHMUNIQUEVALUEINDEX_H
#define QGSALGORITHMUNIQUEVALUEINDEX_H

#define SIP_NO_FILE

#include "qgis_sip.h"
#include "qgsprocessingalgorithm.h"

///@cond PRIVATE

/**
 * Native add unique value index field algorithm.
 */
class QgsAddUniqueValueIndexAlgorithm : public QgsProcessingAlgorithm
{

  public:

    QgsAddUniqueValueIndexAlgorithm() = default;
    void initAlgorithm( const QVariantMap &configuration = QVariantMap() ) override;
    QString name() const override;
    QString displayName() const override;
    QStringList tags() const override;
    QString group() const override;
    QString groupId() const override;
    QString shortHelpString() const override;
    QgsAddUniqueValueIndexAlgorithm *createInstance() const override SIP_FACTORY;

  protected:

    QVariantMap processAlgorithm( const QVariantMap &parameters,
                                  QgsProcessingContext &context, QgsProcessingFeedback *feedback ) override;

};

///@endcond PRIVATE

#endif // QGSALGORITHMUNIQUEVALUEINDEX_H

==> mingw-w64-qgis-3.44.0-2.src.tar.zst: qgis-3.44.0/src/analysis/processing/qgsalgorithmuniquevalueindex.h <==
/***************************************************************************
                         qgsalgorithmuniquevalueindex.h
                         ------------------------------
    begin                : January 2018
    copyright            : (C) 2018 by Nyall Dawson
    email                : nyall dot dawson at gmail dot com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef QGSALGORITHMUNIQUEVALUEINDEX_H
#define QGSALGORITHMUNIQUEVALUEINDEX_H

#define SIP_NO_FILE

#include "qgis_sip.h"
#include "qgsprocessingalgorithm.h"

///@cond PRIVATE

/**
 * Native add unique value index field algorithm.
 */
class QgsAddUniqueValueIndexAlgorithm : public QgsProcessingAlgorithm
{
  public:
    QgsAddUniqueValueIndexAlgorithm() = default;
    void initAlgorithm( const QVariantMap &configuration = QVariantMap() ) override;
    QString name() const override;
    QString displayName() const override;
    QStringList tags() const override;
    QString group() const override;
    QString groupId() const override;
    QString shortHelpString() const override;
    QString shortDescription() const override;
    QgsAddUniqueValueIndexAlgorithm *createInstance() const override SIP_FACTORY;

  protected:
    QVariantMap processAlgorithm( const QVariantMap &parameters, QgsProcessingContext &context, QgsProcessingFeedback *feedback ) override;
};

///@endcond PRIVATE

#endif // QGSALGORITHMUNIQUEVALUEINDEX_H
